@@ -12,6 +12,19 @@ from fairies.file_utils import (
     get_listdir
 )
 
+from fairies.nlp_utils import (
+    split_to_paragraph,
+    split_to_sents,
+    split_to_subsents,
+    jieba_init,
+    jieba_add_words,
+    jieba_cut,
+    isHasMark,
+    label2id,
+    is_chinese,
+    find_lcs
+)
+
 from fairies.extract_utils import (
     read_pdf_by_box,
     read_html,
@@ -20,17 +33,6 @@ from fairies.extract_utils import (
     removeLineFeed
 )
 
-from fairies.nlp_utils import (
-    split_to_paragraph,
-    split_to_sents,
-    split_to_subsents,
-    jieba_add_words,
-    jieba_cut,
-    isHasMark,
-    label2id,
-    is_chinese
-)
-
 from fairies.translate import (
     en_to_zh,
     zh_to_en
