@@ -21,6 +21,6 @@ def write_excel(fileName,sheet_num = 0):
 
     data = xlrd.open_workbook(fileName)
     excel = copy(data)  # 将xlrd的对象转化为xlwt的对象
-    worksheet = excel.get_sheet(0)  # 获取要操作的sheet
+    worksheet = excel.get_sheet(sheet_num)  # 获取要操作的sheet
     
     return excel,worksheet
\ No newline at end of file
