@@ -121,4 +121,4 @@ def get_listdir(path):
         k = os.path.join(path,i)
         res.append(k)
 
-    return k    
\ No newline at end of file
+    return res   
\ No newline at end of file
